@@ -664,22 +664,34 @@ R_DrawAliasModel(entity_t *e)
 
 	if (currententity->flags & RF_WEAPONMODEL)
 	{
-		extern void R_MYgluPerspective(GLdouble fovy, GLdouble aspect,
-				GLdouble zNear, GLdouble zFar);
+		extern void R_MYgluPerspective(GLdouble fovy, GLdouble aspect, GLdouble zNear, GLdouble zFar);
 
 		glMatrixMode(GL_PROJECTION);
 		glPushMatrix();
 		glLoadIdentity();
-		if (gl_lefthand->value == 1.0F)
-			glScalef(-1, 1, 1);
 
-		R_MYgluPerspective(r_gunfov->value, // render weapon with a different FOV so it's not distorted at high view FOV
-				(float)r_newrefdef.width / r_newrefdef.height,
-				4, 4096);
+		if (gl_lefthand->value == 1.0F)
+		{
+			glScalef(-1, 1, 1);
+		}
+
+		float dist = (r_farsee->value == 0) ? 4096.0f : 8192.0f;
+
+		if (r_gunfov->value < 0)
+		{
+			R_MYgluPerspective(r_newrefdef.fov_y, (float)r_newrefdef.width / r_newrefdef.height, 4, dist);
+		}
+		else
+		{
+			R_MYgluPerspective(r_gunfov->value, (float)r_newrefdef.width / r_newrefdef.height, 4, dist);
+		}
+
 		glMatrixMode(GL_MODELVIEW);
 
 		if (gl_lefthand->value == 1.0F)
+		{
 			glCullFace(GL_BACK);
+		}
 	}
 
 	glPushMatrix();
