@@ -123,7 +123,30 @@ qboolean GL3_IsVsyncActive(void)
  */
 void GL3_SetVsync(void)
 {
-	SDL_GL_SetSwapInterval(r_vsync->value ? 1 : 0);
+	// Make sure that the user given
+	// value is SDL compatible...
+	int vsync = 0;
+
+	if (r_vsync->value == 1)
+	{
+		vsync = 1;
+	}
+	else if (r_vsync->value == 2)
+	{
+		vsync = -1;
+	}
+
+	if (SDL_GL_SetSwapInterval(vsync) == -1)
+	{
+		if (vsync == -1)
+		{
+			// Not every system supports adaptive
+			// vsync, fallback to normal vsync.
+			R_Printf(PRINT_ALL, "Failed to set adaptive vsync, reverting to normal vsync.\n");
+			SDL_GL_SetSwapInterval(1);
+		}
+	}
+
 	vsyncActive = SDL_GL_GetSwapInterval() != 0;
 }
 
