@@ -620,6 +620,15 @@ AL_Update(void)
 
 	paintedtime = cls.realtime;
 
+	/* Do nothing if we aren't connected to a output device.
+	   This is called after increasing paintedtime, because
+	   the sound for the current frame needs to be skipped.
+	   Otherwise sound and game will become asynchronous and
+	   the paint buffer may overflow. */
+	if (!QAL_RecoverLostDevice()) {
+         return;
+	}
+
 	/* set listener (player) parameters */
 	AL_CopyVector(listener_forward, orientation);
 	AL_CopyVector(listener_up, orientation + 3);
