@@ -568,7 +568,7 @@ plat_blocked(edict_t *self, edict_t *other)
 				vec3_origin, 100000, 1, 0, MOD_CRUSH);
 
 		/* if it's still there, nuke it */
-		if (other)
+		if (other->inuse)
 		{
 			/* Hack for entity without it's origin near the model */
 			VectorMA (other->absmin, 0.5, other->size, other->s.origin);
@@ -607,6 +607,38 @@ Use_Plat(edict_t *ent, edict_t *other /* unused */, edict_t *activator /* unused
 	plat_go_down(ent);
 }
 
+void
+wait_and_change_think(edict_t* ent)
+{
+	void (*afterwaitfunc)(edict_t *) = ent->moveinfo.endfunc;
+	ent->moveinfo.endfunc = NULL;
+	afterwaitfunc(ent);
+}
+
+/*
+ * In coop mode, this waits for coop_elevator_delay seconds
+ * before calling afterwaitfunc(ent); otherwise it just calls
+ * afterwaitfunc(ent);
+ */
+static void
+wait_and_change(edict_t* ent, void (*afterwaitfunc)(edict_t *))
+{
+	float waittime = coop_elevator_delay->value;
+	if (coop->value && waittime > 0.0f)
+	{
+		if(ent->nextthink == 0)
+		{
+			ent->moveinfo.endfunc = afterwaitfunc;
+			ent->think = wait_and_change_think;
+			ent->nextthink = level.time + waittime;
+		}
+	}
+	else
+	{
+		afterwaitfunc(ent);
+	}
+}
+
 void
 Touch_Plat_Center(edict_t *ent, edict_t *other, cplane_t *plane /* unused */,
 		csurface_t *surf /* unused */)
@@ -630,7 +662,7 @@ Touch_Plat_Center(edict_t *ent, edict_t *other, cplane_t *plane /* unused */,
 
 	if (ent->moveinfo.state == STATE_BOTTOM)
 	{
-		plat_go_up(ent);
+		wait_and_change(ent, plat_go_up);
 	}
 	else if (ent->moveinfo.state == STATE_TOP)
 	{
@@ -659,7 +691,7 @@ plat_spawn_inside_trigger(edict_t *ent)
 
 	tmin[0] = ent->mins[0] + 25;
 	tmin[1] = ent->mins[1] + 25;
-	tmin[2] = ent->mins[2];
+	// tmin[2] = ent->mins[2];
 
 	tmax[0] = ent->maxs[0] - 25;
 	tmax[1] = ent->maxs[1] - 25;
@@ -932,11 +964,6 @@ SP_func_rotating(edict_t *ent)
 
 	ent->use = rotating_use;
 
-	if (ent->dmg)
-	{
-		ent->blocked = rotating_blocked;
-	}
-
 	if (ent->spawnflags & 1)
 	{
 		ent->use(ent, NULL, NULL);
@@ -1602,7 +1629,7 @@ door_blocked(edict_t *self, edict_t *other)
 				vec3_origin, 100000, 1, 0, MOD_CRUSH);
 
 		/* if it's still there, nuke it */
-		if (other)
+		if (other->inuse)
 		{
 			/* Hack for entitiy without their origin near the model */
 			VectorMA (other->absmin, 0.5, other->size, other->s.origin);
@@ -2035,10 +2062,6 @@ SP_func_water(edict_t *self)
 			break;
 
 		case 1: /* water */
-			self->moveinfo.sound_start = gi.soundindex("world/mov_watr.wav");
-			self->moveinfo.sound_end = gi.soundindex("world/stp_watr.wav");
-			break;
-
 		case 2: /* lava */
 			self->moveinfo.sound_start = gi.soundindex("world/mov_watr.wav");
 			self->moveinfo.sound_end = gi.soundindex("world/stp_watr.wav");
@@ -2134,7 +2157,7 @@ train_blocked(edict_t *self, edict_t *other)
 				vec3_origin, 100000, 1, 0, MOD_CRUSH);
 
 		/* if it's still there, nuke it */
-		if (other)
+		if (other->inuse)
 		{
 			/* Hack for entity without an origin near the model */
 			VectorMA (other->absmin, 0.5, other->size, other->s.origin);
@@ -2831,7 +2854,7 @@ door_secret_blocked(edict_t *self, edict_t *other)
 				vec3_origin, 100000, 1, 0, MOD_CRUSH);
 
 		/* if it's still there, nuke it */
-		if (other)
+		if (other->inuse)
 		{
 			/* Hack for entities without their origin near the model */
 			VectorMA (other->absmin, 0.5, other->size, other->s.origin);
