@@ -26,8 +26,8 @@
 
 #include "header/local.h"
 
+int debristhisframe;
 int gibsthisframe;
-int lastgibframe;
 
 void
 Use_Areaportal(edict_t *ent, edict_t *other /* unused */, edict_t *activator /* unused */)
@@ -138,7 +138,7 @@ gib_think(edict_t *self)
 void
 gib_touch(edict_t *self, edict_t *other /* unused */, cplane_t *plane, csurface_t *surf /* unused */)
 {
-	if (!self || !plane)
+	if (!self)
 	{
 		return;
 	}
@@ -196,15 +196,9 @@ ThrowGib(edict_t *self, char *gibname, int damage, int type)
 		return;
 	}
 
-	if (level.framenum > lastgibframe)
-	{
-		gibsthisframe = 0;
-		lastgibframe = level.framenum;
-	}
-
 	gibsthisframe++;
 
-	if (gibsthisframe > 20)
+	if (gibsthisframe > MAX_GIBS)
 	{
 		return;
 	}
@@ -223,6 +217,7 @@ ThrowGib(edict_t *self, char *gibname, int damage, int type)
 	gib->flags |= FL_NO_KNOCKBACK;
 	gib->takedamage = DAMAGE_YES;
 	gib->die = gib_die;
+	gib->health = 250;
 
 	if (type == GIB_ORGANIC)
 	{
@@ -378,15 +373,9 @@ ThrowDebris(edict_t *self, char *modelname, float speed, vec3_t origin)
 		return;
 	}
 
-	if (level.framenum > lastgibframe)
-	{
-		gibsthisframe = 0;
-		lastgibframe = level.framenum;
-	}
+	debristhisframe++;
 
-	gibsthisframe++;
-
-	if (gibsthisframe > 20)
+	if (debristhisframe > MAX_DEBRIS)
 	{
 		return;
 	}
@@ -410,6 +399,7 @@ ThrowDebris(edict_t *self, char *modelname, float speed, vec3_t origin)
 	chunk->classname = "debris";
 	chunk->takedamage = DAMAGE_YES;
 	chunk->die = debris_die;
+	chunk->health = 250;
 	gi.linkentity(chunk);
 }
 
@@ -902,13 +892,9 @@ void
 func_object_touch(edict_t *self, edict_t *other, cplane_t *plane,
 		csurface_t *surf /* unused */)
 {
-	if (!self || !other || !plane)
-	{
-		return;
-	}
-
 	/* only squash thing we fall on top of */
-	if (!plane)
+
+	if (!self || !other || !plane)
 	{
 		return;
 	}
