@@ -547,7 +547,7 @@ brain_tentacle_attack(edict_t *self)
 
 	VectorSet(aim, MELEE_DISTANCE, 0, 8);
 
-	if (fire_hit(self, aim, (10 + (randk() % 5)), -600) && (skill->value > 0))
+	if (fire_hit(self, aim, (10 + (randk() % 5)), -600) && (skill->value > SKILL_EASY))
 	{
 		self->spawnflags |= 65536;
 	}
@@ -683,7 +683,7 @@ brain_pain(edict_t *self, edict_t *other /* unused */,
 
 	self->pain_debounce_time = level.time + 3;
 
-	if (skill->value == 3)
+	if (skill->value == SKILL_HARDPLUS)
 	{
 		return; /* no pain anims in nightmare */
 	}
