@@ -403,7 +403,7 @@ tank_pain(edict_t *self, edict_t *other /* other */,
 	}
 
 	/* If hard or nightmare, don't go into pain while attacking */
-	if (skill->value >= 2)
+	if (skill->value >= SKILL_HARD)
 	{
 		if ((self->s.frame >= FRAME_attak301) &&
 			(self->s.frame <= FRAME_attak330))
@@ -421,7 +421,7 @@ tank_pain(edict_t *self, edict_t *other /* other */,
 	self->pain_debounce_time = level.time + 3;
 	gi.sound(self, CHAN_VOICE, sound_pain, 1, ATTN_NORM, 0);
 
-	if (skill->value == 3)
+	if (skill->value == SKILL_HARDPLUS)
 	{
 		return; /* no pain anims in nightmare */
 	}
@@ -643,7 +643,7 @@ tank_reattack_blaster(edict_t *self)
 		return;
 	}
 
-	if (skill->value >= 2)
+	if (skill->value >= SKILL_HARD)
 	{
 		if (visible(self, self->enemy))
 		{
@@ -861,7 +861,7 @@ tank_refire_rocket(edict_t *self)
 	}
 
 	/* Only on hard or nightmare */
-	if (skill->value >= 2)
+	if (skill->value >= SKILL_HARD)
 	{
 		if (self->enemy->health > 0)
 		{
